@@ -255,7 +255,7 @@ class DesktopTarget extends EventEmitter {
         this._desktopDestroyedId = 0;
 
         this._windowAddedId =
-            global.window_group.connect('actor-added',
+            global.window_group.connect('child-added',
                 this._onWindowAdded.bind(this));
 
         global.get_window_actors().forEach(a => {
@@ -394,12 +394,12 @@ class ApplicationsButton extends PanelMenu.Button {
         this.accessible_role = Atk.Role.LABEL;
 
         this._label = new St.Label({
-            text: _('Applications'),
+            text: _('Apps'),
             y_expand: true,
             y_align: Clutter.ActorAlign.CENTER,
         });
 
-        this.add_actor(this._label);
+        this.add_child(this._label);
         this.name = 'panelApplications';
         this.label_actor = this._label;
 
@@ -512,7 +512,7 @@ class ApplicationsButton extends PanelMenu.Button {
     }
 
     scrollToButton(button) {
-        let appsScrollBoxAdj = this.applicationsScrollBox.get_vscroll_bar().get_adjustment();
+        let appsScrollBoxAdj = this.applicationsScrollBox.get_vadjustment();
         let appsScrollBoxAlloc = this.applicationsScrollBox.get_allocation_box();
         let currentScrollValue = appsScrollBoxAdj.get_value();
         let boxHeight = appsScrollBoxAlloc.y2 - appsScrollBoxAlloc.y1;
@@ -527,7 +527,7 @@ class ApplicationsButton extends PanelMenu.Button {
     }
 
     scrollToCatButton(button) {
-        let catsScrollBoxAdj = this.categoriesScrollBox.get_vscroll_bar().get_adjustment();
+        let catsScrollBoxAdj = this.categoriesScrollBox.get_vadjustment();
         let catsScrollBoxAlloc = this.categoriesScrollBox.get_allocation_box();
         let currentScrollValue = catsScrollBoxAdj.get_value();
         let boxHeight = catsScrollBoxAlloc.y2 - catsScrollBoxAlloc.y1;
@@ -550,31 +550,19 @@ class ApplicationsButton extends PanelMenu.Button {
             style_class: 'apps-menu vfade',
             x_expand: true,
         });
-        this.applicationsScrollBox.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
-        let vscroll = this.applicationsScrollBox.get_vscroll_bar();
-        vscroll.connect('scroll-start', () => {
-            this.menu.passEvents = true;
-        });
-        vscroll.connect('scroll-stop', () => {
-            this.menu.passEvents = false;
-        });
         this.categoriesScrollBox = new St.ScrollView({
             style_class: 'vfade',
         });
-        this.categoriesScrollBox.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC);
-        vscroll = this.categoriesScrollBox.get_vscroll_bar();
-        vscroll.connect('scroll-start', () => (this.menu.passEvents = true));
-        vscroll.connect('scroll-stop', () => (this.menu.passEvents = false));
         this.leftBox.add_child(this.categoriesScrollBox);
 
         this.applicationsBox = new St.BoxLayout({vertical: true});
-        this.applicationsScrollBox.add_actor(this.applicationsBox);
+        this.applicationsScrollBox.set_child(this.applicationsBox);
         this.categoriesBox = new St.BoxLayout({vertical: true});
-        this.categoriesScrollBox.add_actor(this.categoriesBox);
+        this.categoriesScrollBox.set_child(this.categoriesBox);
 
-        this.mainBox.add(this.leftBox);
+        this.mainBox.add_child(this.leftBox);
         this.mainBox.add_child(this.applicationsScrollBox);
-        section.actor.add_actor(this.mainBox);
+        section.actor.add_child(this.mainBox);
     }
 
     _display() {
@@ -586,7 +574,7 @@ class ApplicationsButton extends PanelMenu.Button {
         this._tree.load_sync();
         let root = this._tree.get_root_directory();
         let categoryMenuItem = new CategoryMenuItem(this, null);
-        this.categoriesBox.add_actor(categoryMenuItem);
+        this.categoriesBox.add_child(categoryMenuItem);
         let iter = root.iter();
         let nextType;
         while ((nextType = iter.next()) !== GMenu.TreeItemType.INVALID) {
@@ -602,7 +590,7 @@ class ApplicationsButton extends PanelMenu.Button {
             this._loadCategory(categoryId, dir);
             if (this.applicationsByCategory[categoryId].length > 0) {
                 categoryMenuItem = new CategoryMenuItem(this, dir);
-                this.categoriesBox.add_actor(categoryMenuItem);
+                this.categoriesBox.add_child(categoryMenuItem);
             }
         }
 
@@ -615,7 +603,7 @@ class ApplicationsButton extends PanelMenu.Button {
             if (c._delegate instanceof PopupMenu.PopupSeparatorMenuItem)
                 c._delegate.destroy();
             else
-                this.applicationsBox.remove_actor(c);
+                this.applicationsBox.remove_child(c);
         });
 
         if (dir)
@@ -638,7 +626,7 @@ class ApplicationsButton extends PanelMenu.Button {
                 this._applicationsButtons.set(app, item);
             }
             if (!item.get_parent())
-                this.applicationsBox.add_actor(item);
+                this.applicationsBox.add_child(item);
         }
     }
 
